@@ -572,6 +572,8 @@ static t_int *sigrpole_perform(t_int *w)
         float coef = *in2++;
         *out++ = last = coef * last + next;
     }
+    if (PD_BIGORSMALL(last))
+        last = 0;
     x->x_last = last;
     return (w+6);
 }
@@ -803,6 +805,10 @@ static t_int *sigcpole_perform(t_int *w)
         lastim = *outim++ = nextim + lastre * coefim + lastim * coefre;
         lastre = tempre;
     }
+    if (PD_BIGORSMALL(lastre))
+        lastre = 0;
+    if (PD_BIGORSMALL(lastim))
+        lastim = 0;
     x->x_lastre = lastre;
     x->x_lastim = lastim;
     return (w+9);
